==> qtjambi-quick-debuginfo-macos-6.5.3.jar: sources/QtJambiQuick/QQuickWindow_shell.h <==
#ifndef QQUICKWINDOW_SHELL_H
#define QQUICKWINDOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qquickwindow.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qrunnable.h>
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qimage.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <QtQml/qqmlincubator.h>
#include <QtQuick/private/qquickevents_p_p.h>
#include <QtQuick/qquickgraphicsconfiguration.h>
#include <QtQuick/qquickgraphicsdevice.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickrendercontrol.h>
#include <QtQuick/qquickrendertarget.h>
#include <QtQuick/qsgimagenode.h>
#include <QtQuick/qsgninepatchnode.h>
#include <QtQuick/qsgrectanglenode.h>
#include <QtQuick/qsgrendererinterface.h>
#include <QtQuick/qsgtexture.h>
#include <QtJambi/RegistryAPI>


class QQuickWindow_shell : public QQuickWindow, public QtJambiShellInterface
{
public:
    QQuickWindow_shell(QQuickRenderControl* renderControl0);
    QQuickWindow_shell(QWindow* parent0 = nullptr);
    ~QQuickWindow_shell() override;

    QAccessibleInterface* accessibleRoot() const override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* arg__1) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void exposeEvent(QExposeEvent* arg__1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    QObject* focusObject() const override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    QSurfaceFormat format() const override;
    void hideEvent(QHideEvent* arg__1) override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* arg__1) override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* arg__1) override;
    void paintEvent(QPaintEvent* arg__1) override;
    void resizeEvent(QResizeEvent* arg__1) override;
    void showEvent(QShowEvent* arg__1) override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void tabletEvent(QTabletEvent* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* arg__1) override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickWindow_access : public QQuickWindow
{
    jobject __qt_accessibleRoot(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_closeEvent_QCloseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_exposeEvent_QExposeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_focusObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_hideEvent_QHideEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_mouseDoubleClickEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_tabletEvent_QTabletEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QQUICKWINDOW_SHELL_H

==> qtjambi-quick-debuginfo-macos-6.5.6.jar: sources/QtJambiQuick/QQuickWindow_shell.h <==
#ifndef QQUICKWINDOW_SHELL_H
#define QQUICKWINDOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickwindow.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qrunnable.h>
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qimage.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <QtQml/qqmlincubator.h>
#include <QtQuick/private/qquickevents_p_p.h>
#include <QtQuick/qquickgraphicsconfiguration.h>
#include <QtQuick/qquickgraphicsdevice.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickrendercontrol.h>
#include <QtQuick/qquickrendertarget.h>
#include <QtQuick/qsgimagenode.h>
#include <QtQuick/qsgninepatchnode.h>
#include <QtQuick/qsgrectanglenode.h>
#include <QtQuick/qsgrendererinterface.h>
#include <QtQuick/qsgtexture.h>
#include <QtJambi/RegistryAPI>


class QQuickWindow_shell : public QQuickWindow, public QtJambiShellInterface
{
public:
    QQuickWindow_shell(QQuickRenderControl* renderControl0);
    QQuickWindow_shell(QWindow* parent0 = nullptr);
    ~QQuickWindow_shell() override;

    QAccessibleInterface* accessibleRoot() const override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* arg__1) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void exposeEvent(QExposeEvent* arg__1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    QObject* focusObject() const override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    QSurfaceFormat format() const override;
    void hideEvent(QHideEvent* arg__1) override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* arg__1) override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* arg__1) override;
    void paintEvent(QPaintEvent* arg__1) override;
    void resizeEvent(QResizeEvent* arg__1) override;
    void showEvent(QShowEvent* arg__1) override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void tabletEvent(QTabletEvent* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* arg__1) override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickWindow_access : public QQuickWindow
{
    jobject __qt_accessibleRoot_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_closeEvent_QCloseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_exposeEvent_QExposeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_focusObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_hideEvent_QHideEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_mouseDoubleClickEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_tabletEvent_QTabletEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QQUICKWINDOW_SHELL_H
